@@ -2,7 +2,7 @@ from django.apps import AppConfig
 
 
 class GqlAuthConfig(AppConfig):
-    default_auto_field = 'django.db.models.BigAutoField'
+    default_auto_field = "django.db.models.BigAutoField"
     name = "gqlauth"
     verbose_name = "GraphQL Auth"
 
