@@ -38,8 +38,9 @@ class WrongUsage(GraphQLAuthError):
     """
     internal exception
     """
+
     default_message = _("Wrong usage, check your code!.")
 
 
-class NoSufficiantPermissions(GraphQLAuthError):
+class PermissionDenied(GraphQLAuthError):
     default_message = _("User is not allowed for this content")
