@@ -23,43 +23,46 @@ from gqlauth.user.resolvers import (
     SwapEmailsMixin,
     RemoveSecondaryEmailMixin,
 )
+from strawberry_django_jwt.mutations import ObtainJSONWebToken as JwtObtainParent
+from strawberry_django_jwt.mutations import Verify as VerifyParent
+from strawberry_django_jwt.mutations import Revoke as RevokeParent
+from strawberry_django_jwt.mutations import Refresh as RefreshParent
+
+
 class Register(
     RegisterMixin, DynamicArgsMixin, DynamicPayloadMixin, DynamicArgsMutationMixin
 ):
     __doc__ = RegisterMixin.__doc__
 
-from strawberry_django_jwt.mutations import  Verify as VerifyParent
+
 class VerifyAccount(
     VerifyAccountMixin,
     DynamicArgsMixin,
     DynamicPayloadMixin,
     DynamicArgsMutationMixin,
-    VerifyParent
+    VerifyParent,
 ):
     __doc__ = VerifyAccountMixin.__doc__
 
 
-
 class ResendActivationEmail(
     ResendActivationEmailMixin,
     DynamicArgsMixin,
     DynamicPayloadMixin,
-    DynamicArgsMutationMixin
+    DynamicArgsMutationMixin,
 ):
     __doc__ = ResendActivationEmailMixin.__doc__
 
 
-
 class SendPasswordResetEmail(
     SendPasswordResetEmailMixin,
     DynamicArgsMixin,
     DynamicPayloadMixin,
-    DynamicArgsMutationMixin
+    DynamicArgsMutationMixin,
 ):
     __doc__ = SendPasswordResetEmailMixin.__doc__
 
 
-
 class SendSecondaryEmailActivation(
     SendSecondaryEmailActivationMixin,
     DynamicArgsMixin,
@@ -69,7 +72,6 @@ class SendSecondaryEmailActivation(
     __doc__ = SendSecondaryEmailActivationMixin.__doc__
 
 
-
 class VerifySecondaryEmail(
     VerifySecondaryEmailMixin,
     DynamicArgsMixin,
@@ -79,7 +81,6 @@ class VerifySecondaryEmail(
     __doc__ = VerifySecondaryEmailMixin.__doc__
 
 
-
 class SwapEmails(
     SwapEmailsMixin,
     DynamicArgsMixin,
@@ -89,7 +90,6 @@ class SwapEmails(
     __doc__ = SwapEmailsMixin.__doc__
 
 
-
 class RemoveSecondaryEmail(
     RemoveSecondaryEmailMixin,
     DynamicArgsMixin,
@@ -99,7 +99,6 @@ class RemoveSecondaryEmail(
     __doc__ = RemoveSecondaryEmailMixin.__doc__
 
 
-
 class PasswordSet(
     PasswordSetMixin,
     DynamicArgsMixin,
@@ -109,7 +108,6 @@ class PasswordSet(
     __doc__ = PasswordSetMixin.__doc__
 
 
-
 class PasswordReset(
     PasswordResetMixin,
     DynamicArgsMixin,
@@ -118,7 +116,7 @@ class PasswordReset(
 ):
     __doc__ = PasswordResetMixin.__doc__
 
-from strawberry_django_jwt.mutations import ObtainJSONWebToken as JwtObtainParent
+
 class ObtainJSONWebToken(
     ObtainJSONWebTokenMixin,
     DynamicArgsMixin,
@@ -129,8 +127,6 @@ class ObtainJSONWebToken(
     __doc__ = ObtainJSONWebTokenMixin.__doc__
 
 
-
-
 class ArchiveAccount(
     ArchiveAccountMixin,
     DynamicArgsMixin,
@@ -140,7 +136,6 @@ class ArchiveAccount(
     __doc__ = ArchiveAccountMixin.__doc__
 
 
-
 class DeleteAccount(
     DeleteAccountMixin,
     DynamicArgsMixin,
@@ -150,18 +145,16 @@ class DeleteAccount(
     __doc__ = DeleteAccountMixin.__doc__
 
 
-
 class PasswordChange(
     PasswordChangeMixin,
     DynamicArgsMixin,
     DynamicPayloadMixin,
     DynamicArgsMutationMixin,
-    JwtObtainParent
+    JwtObtainParent,
 ):
     __doc__ = PasswordChangeMixin.__doc__
 
 
-
 class UpdateAccount(
     UpdateAccountMixin,
     DynamicArgsMixin,
@@ -171,37 +164,31 @@ class UpdateAccount(
     __doc__ = UpdateAccountMixin.__doc__
 
 
-from strawberry_django_jwt.mutations import Verify as VerifyParent
 class VerifyToken(
     VerifyTokenMixin,
     DynamicArgsMixin,
     DynamicPayloadMixin,
     DynamicArgsMutationMixin,
-    VerifyParent
+    VerifyParent,
 ):
     __doc__ = VerifyTokenMixin.__doc__
 
 
-
-from strawberry_django_jwt.mutations import Refresh
 class RefreshToken(
     RefreshTokenMixin,
     DynamicArgsMixin,
     DynamicPayloadMixin,
     DynamicArgsMutationMixin,
-    Refresh
+    RefreshParent,
 ):
     __doc__ = RefreshTokenMixin.__doc__
 
 
-from strawberry_django_jwt.mutations import Revoke as RevokeParent
-
 class RevokeToken(
     RevokeTokenMixin,
     DynamicArgsMixin,
     DynamicPayloadMixin,
     DynamicArgsMutationMixin,
-    RevokeParent
+    RevokeParent,
 ):
     __doc__ = RevokeTokenMixin.__doc__
-
