@@ -17,7 +17,7 @@ from django.contrib import admin
 from django.urls import path
 from strawberry.django.views import GraphQLView
 from django.views.decorators.csrf import csrf_exempt
-from schema import schema
+from .schema import schema
 
 urlpatterns = [
     path("admin/", admin.site.urls),
